@@ -48,7 +48,11 @@ FilterParametersWidget::FilterParametersWidget(QWidget * parent) : QWidget(paren
   _hasKeypoints = false;
 }
 
-QVector<AbstractParameter *> FilterParametersWidget::buildParameters(const QString & parameters, QObject * parent, int * actualParameterCount, QString * error)
+QVector<AbstractParameter *> FilterParametersWidget::buildParameters(const QString & filterName, //
+                                                                     const QString & parameters, //
+                                                                     QObject * parent,           //
+                                                                     int * actualParameterCount, //
+                                                                     QString * error)
 {
   QVector<AbstractParameter *> result;
   QByteArray rawText = parameters.toUtf8();
@@ -59,7 +63,7 @@ QVector<AbstractParameter *> FilterParametersWidget::buildParameters(const QStri
 
   AbstractParameter * parameter;
   do {
-    parameter = AbstractParameter::createFromText(cstr, length, localError, parent);
+    parameter = AbstractParameter::createFromText(filterName, cstr, length, localError, parent);
     if (parameter) {
       result.push_back(parameter);
       if (parameter->isActualParameter()) {
@@ -114,7 +118,7 @@ QStringList FilterParametersWidget::defaultParameterList(const QString & paramet
   }
   QObject parent;
   QString localError;
-  QVector<AbstractParameter *> v = FilterParametersWidget::buildParameters(parametersDefinition, &parent, nullptr, &localError);
+  QVector<AbstractParameter *> v = FilterParametersWidget::buildParameters("Dummy filter", parametersDefinition, &parent, nullptr, &localError);
   if (!localError.isEmpty()) {
     if (error) {
       *error = localError;
@@ -162,7 +166,7 @@ bool FilterParametersWidget::build(const QString & name, const QString & hash, c
 
   // Build parameters and count actual ones
   QString error;
-  _parameters = buildParameters(parameters, this, &_actualParametersCount, &error);
+  _parameters = buildParameters(_filterName, parameters, this, &_actualParametersCount, &error);
   _quotedParameters = quotedParameters(_parameters);
 
   // Restore saved values
@@ -187,7 +191,7 @@ bool FilterParametersWidget::build(const QString & name, const QString & hash, c
       grid->setRowStretch(row, 0);
       ++row;
     }
-    connect(parameter, SIGNAL(valueChanged()), this, SLOT(updateValueString()));
+    connect(parameter, &AbstractParameter::valueChanged, this, &FilterParametersWidget::updateValueStringAndNotify);
     ++it;
   }
 
@@ -332,7 +336,7 @@ void FilterParametersWidget::setVisibilityStates(const QList<int> & states)
           (parameter->visibilityPropagation() == AbstractParameter::VisibilityPropagation::UpDown)) {
         int i = n - 1;
         while ((i >= 0) && !_parameters[i]->isActualParameter()) {
-          newVisibilityStates[i++] = state;
+          newVisibilityStates[i--] = state;
         }
       }
       if ((parameter->visibilityPropagation() == AbstractParameter::VisibilityPropagation::Down) || //
@@ -445,6 +449,11 @@ void FilterParametersWidget::updateValueString(bool notify)
   }
 }
 
+void FilterParametersWidget::updateValueStringAndNotify()
+{
+  updateValueString(true);
+}
+
 void FilterParametersWidget::clear()
 {
   QVector<AbstractParameter *>::iterator it = _parameters.begin();
